@@ -2,7 +2,7 @@
 
 import unittest
 
-from .. import utils
+from jwt import utils
 
 
 class TestUtils(unittest.TestCase):
@@ -12,8 +12,8 @@ class TestUtils(unittest.TestCase):
             + b'"http://example.com/is_root":true}'
         self.assertEqual(
             utils.b64_encode(ret),
-            b'eyJpc3MiOiJqb2UiLA0KICJleHAiOjEzMDA4MTkzODAsDQog'
-            b'Imh0dHA6Ly9leGFtcGxlLmNvbS9pc19yb290Ijp0cnVlfQ',
+            'eyJpc3MiOiJqb2UiLA0KICJleHAiOjEzMDA4MTkzODAsDQog'
+            'Imh0dHA6Ly9leGFtcGxlLmNvbS9pc19yb290Ijp0cnVlfQ',
         )
 
     def test_b64_decode(self):
@@ -24,3 +24,9 @@ class TestUtils(unittest.TestCase):
             b'{"iss":"joe",\r\n "exp":1300819380,\r\n '
             b'"http://example.com/is_root":true}'
         )
+
+    def test_base64_to_int(self):
+        self.assertEqual(utils.base64_to_int(b'AQAB'), 65537)
+
+    def test_int_to_base64(self):
+        self.assertEqual(utils.int_to_base64(65537), 'AQAB')
